# ✨ Welcome to panel-material-ui

[![License](https://img.shields.io/badge/License-MIT%202.0-blue.svg)](https://opensource.org/licenses/MIT)
[![CI](https://img.shields.io/github/actions/workflow/status/panel-extensions/panel-material-ui/ci.yml?style=flat-square&branch=main)](https://github.com/panel-extensions/panel-material-ui/actions/workflows/ci.yml)
[![conda-forge](https://img.shields.io/conda/vn/conda-forge/panel-material-ui?logoColor=white&logo=conda-forge&style=flat-square)](https://prefix.dev/channels/conda-forge/packages/panel-material-ui)
[![pypi-version](https://img.shields.io/pypi/v/panel-material-ui.svg?logo=pypi&logoColor=white&style=flat-square)](https://pypi.org/project/panel-material-ui)
[![python-version](https://img.shields.io/pypi/pyversions/panel-material-ui?logoColor=white&logo=python&style=flat-square)](https://pypi.org/project/panel-material-ui)

An extension to bring MaterialUI components to Panel.

## Installation

Install `panel-material-ui` via `pip`:

```bash
pip install panel-material-ui
```

## ❤️ Contributions

Contributions and co-maintainers are very welcome! Please submit issues or pull requests to the [GitHub repository](https://github.com/panel-extensions/panel-material-ui). Check out the [DEVELOPER_GUIDE](DEVELOPER_GUIDE.md) for more information.
